17. Installation — jscatter 0.7.3.3 documentation

# 17. Installation

- Dependencies

  numpy, scipy (automatically installed by pip)

  gfortran, without some functions dont work:

      sudo apt-get install gfortran

  recommended:

  xmgrace for plotting in Linux (Ubuntu, Debian)

      sudo apt-get install grace

  xmgrace for plotting in MacOs (install XQuartz and Homebrew):

      brew tap homebrew/x11
      brew install grace

  Ipython for convenience

  matplotlib (needed for 3D plots):

      pip install ipython matplotlib

- Installation (maybe use pip2 or pip3 dependent what you want to use)

      pip install jscatter

  as user in home directory:

      pip install jscatter --user

  from a local repository (development versions):

      pip install jscatter --user --upgrade --pre --find-links /where/the/file/is/saved

      options
      --user       : Install in user directory (folder defined by PYTHONUSERBASE or the default is used)
      --find-links : look in the given path for package links e.g development releases
      --upgrade    : to install upgrades
      --pre        : to install also development versions

- Anaconda is a python distribution as easy alternative for MacOs and Windows (also working on Linux) with numpy, scipy, matplotlib, Ipython preinstalled.

      pip install jscatter

      # install xmgrace (only Linux/OSX)
      conda install -c uvcdat xmgrace

- CONTIN in DLS module

  See DLS module documentation for details how to get and compile the original fortran code. Only if needed.

- Testing

  You can test basic functionality of jscatter after installation:

      import jscatter as js
      js.test.doTest()

  During development:

      python setup.py test